<?PHP // $Id$ 
      // moodle.php - created with Moodle 1.1.1 (2003091111)


$string['action'] = "Tevkenysg";
$string['activities'] = "Tevkenysgek";
$string['activity'] = "Tevkenysg";
$string['activityclipboard'] = "A kvetkez tevkenysg mozgatsa: <b>\$a</b>";
$string['activityiscurrentlyhidden'] = "Ez a a tevkenysg jelenleg rejtett";
$string['activitymodule'] = "Tevkenysg modul";
$string['activityreport'] = "Tevkenysg tudstsa";
$string['activityselect'] = "A tevkenysg kivlasztsa tmozgatsra";
$string['activitysince'] = "Aktivits \$a idpont ta";
$string['add'] = "Hozzads";
$string['addadmin'] = "Admin hozzadsa";
$string['addcreator'] = "Kurzuskszt hozzadsa";
$string['added'] = "\$a hozzadva";
$string['addinganew'] = "j \$a hozzadsa";
$string['addinganewto'] = "j \$a->what hozzadsa \$a->to -hoz";
$string['addnewcategory'] = "j kategria hozzadsa";
$string['addnewcourse'] = "j tanfolyam hozzadsa";
$string['addnewuser'] = "j felhasznl hozzadsa";
$string['address'] = "Cm";
$string['addstudent'] = "Rsztvev hozzadsa";
$string['addteacher'] = "Tanr hozzadsa";
$string['admin'] = "Admin";
$string['adminhelpaddnewuser'] = "j felhasznl manulis ltrehozsa";
$string['adminhelpassignadmins'] = "Adminok b rmit csinlhatnak s brhov mehetnek az oldalon";
$string['adminhelpassigncreators'] = "Kurzusksztk j kurzusokat hozhatnak ltre s azokban tanthatnak";
$string['administration'] = "Adminisztrci";
$string['administrator'] = "Adminisztrtor";
$string['administrators'] = "Adminisztrtorok";
$string['again'] = "ismt";
$string['all'] = "Minden";
$string['alldays'] = "Minden nap";
$string['allfieldsrequired'] = "Minden mez ktelez";
$string['alllogs'] = "Minden naplbejegyzs";
$string['allow'] = "Engedlyezve";
$string['allowguests'] = "Ez a kurzus megengedi vendgek belpst";
$string['allownot'] = "Nincs engedlyezve";
$string['allparticipants'] = "Minden rsztvev";
$string['alphanumerical'] = "Csak alfanumerikus karaktereket tartalmazhat";
$string['alreadyconfirmed'] = "A regisztrci mr megerstst nyert";
$string['answer'] = "Vlasz";
$string['areyousuretorestorethis'] = "Kvnja folytatni?";
$string['assessment'] = "rtkels";
$string['assignadmins'] = "Adminok hozzrendelse";
$string['assignstudents'] = "Rsztvev beiratsa";
$string['assignteachers'] = "Tanrok hozzrendelse";
$string['authentication'] = "Hitelests";
$string['autosubscribe'] = "Automatikus feliratkozs a frumra";
$string['autosubscribeno'] = "Nem: nem iratkozom automatikusan a frumokra";
$string['autosubscribeyes'] = "Igen: ha hozzszlok, feliratkozok a frumra";
$string['availability'] = "Elrhetsg";
$string['availablecourses'] = "Elrhet tanfolyamok";
$string['backup'] = "Biztonsgi ments";
$string['backupdate'] = "Biztonsgi ments dtuma";
$string['backupdetails'] = "Biztonsgi ments rszletei";
$string['backupfilename'] = "biztonsgi ments";
$string['backupfinished'] = "A biztonsgi ments sikerlt";
$string['backupnameformat'] = "%%Y%%m%%d-%%H%%M";
$string['backuporiginalname'] = "Ments neve";
$string['backupversion'] = "Ments verziszma";
$string['cancel'] = "Mgsem";
$string['categories'] = "Tanfolyam kategrik";
$string['category'] = "Kategria";
$string['categoryadded'] = "A '\$a' kategria hozzadsa megtrtnt";
$string['categorydeleted'] = "A '\$a' kategria trlse megtrtnt";
$string['categoryduplicate'] = "'\$a' nev kategria mr ltezik!";
$string['changedpassword'] = "Megvltozott jelsz";
$string['changepassword'] = "Jelsz megvltoztatsa";
$string['changessaved'] = "Vltozsok mentse";
$string['checkingbackup'] = "Ments ellenrzse";
$string['checkingcourse'] = "Kurzus ellenrzse";
$string['checkinginstances'] = "Pldnyok ellenrzse";
$string['checkingsections'] = "Szekcik ellenrzse";
$string['checklanguage'] = "Nyelv ellenrzse";
$string['choose'] = "Vlaszzon";
$string['choosecourse'] = "Vlasszon tanfolyamot";
$string['chooselivelogs'] = "Vagy nzzen jelenlegi tevkenysget";
$string['chooselogs'] = "Vlassza ki a ltni kvnt naplbejegyzseket";
$string['choosetheme'] = "Vlasszon stlust";
$string['chooseuser'] = "Vlasszon felasznlt";
$string['city'] = "Vros/falu";
$string['cleaningtempdata'] = "Ideiglenes adatok trlse";
$string['closewindow'] = "Ablak bezrsa";
$string['comparelanguage'] = "Az aktulis nyelv ellenrzse s szerkesztse";
$string['complete'] = "Ksz";
$string['configcountry'] = "Az itt belltott orszg lesz az alaprtelmezett j felhasznlk szmra. Ha a felhasznlknak vlasztaniuk kell nyelvet, hagyja ezt resen.";
$string['configdebug'] = "Ennek bekapcsolsval a PHP hibazenetei szaporodnak, tbb figyelmeztet zenet fog megjelenni. Csak fejlesztk szmra hasznos.";
$string['configerrorlevel'] = "Vlassza ki a PHP zenetek kvnt mennyisgt.  ltalban a Norml a legjobb vlaszts.";
$string['configgdversion'] = "A teleptett GD verzit jelzi. Az alaprtelmezett rtk az automatikusan felismert teleptett verzi szma. Ne vltoztassa, csak ha valban tudja, mit csinl.";
$string['confightmleditor'] = "Megengedi-e vagy sem a beptett HTML szerkeszt hasznlatt. Ha meg is engedi, csak akkor jelenik meg, ha a felhasznl megfelel bngszt hasznl (IE 5.5 vagy jabb). A felhasznlk szintn vlaszthatjk azt, hogy nem hasznljk.";
$string['configintro'] = "Ezen az oldalon megadhatja azon a konfigurcis vltozk szmt, amelyek elsegtik a Moodle problmamentes hasznlatt a szervern. Ne trdjn tl sokat ezzel - az alaprtelmezett rtkek ltalban megfelelek s ksbb brmikor visszatrhet erre az oldalra, hogy mdostsa a belltsokat.";
$string['configlang'] = "Vlassza ki az oldal alprtelmezett nyelvt. A felhasznlk ksbb ezt a sajt rszkre megvltoztathatjk.";
$string['configlangdir'] = "A legtbb nyelv balrl jobbra r, de nhny, mint pl. az arab vagy a hber jobbrl balra.";
$string['configlocale'] = "Vlassza ki az egsz oldalra rvnyes terleti belltsokat - ez a nyelvi s dtum formtumokat rinti. A terleti bellts teleptve kell lennie a rendszeren.  (pl. en_US vagy es_ES). Ha nem tudja melyiket vlassza, hagyja resen.";
$string['configlongtimenosee'] = "Ha a felhasznlk hossz ideig nem lpnek be, automatikusan ki lesznek iratva a kurzusokrl.  Ez a paramter ezt az idkorltot adja meg.";
$string['configmaxeditingtime'] = "Az idintervallumot adja meg, melyen bell a felhasznlk javthatjk a frum-hozzszlsaikat, naplbejegyzseiket stb. 30 perc ltalban megfelel rtk.";
$string['configproxyhost'] = "Ha ez a <B>szerver</B> proxy-t ignyel (pl. egy tzfalat) az Internet-elrshez, ide rja a proxy nevt s portszmt, egybknt hagyja resen.";
$string['configslasharguments'] = "A fjlok (kpek, feltltsek stb) egy 'perjeles paramtereket' hasznl szkripten keresztl rkeznek (itt a msodik lehetsg). Ez lehetv teszi a fjlok knnyebb cache-elst bngszk, proxy-k stb. szmra. Sajnos nmely PHP szerverek nem engedik ezt a mdszert, ezrt ha problmja van feltlttt fjlok megtekintsvel (pl. felhasznlk kpei), lltsa ezt a vltozt az els lehetsgre.";
$string['configsmtphosts'] = "Adja meg egy vagy tbb helyi SMTP szerver teljes nevt, melyeket a Moodle hasznlhat email kldsre(pl. 'mail.a.com' vagy 'mail.a.com;mail.b.com'). Ha resen hagyja, a Moodle az alaprtelmezett PHP email kldsi mdszert fogja hasznlni.";
$string['configsmtpuser'] = "Ha fentebb megadott SMTP szervert, s a szerver felhasznl-azonostst ignyel, adja meg itt a felhasznlnevet s jelszt.";
$string['configunzip'] = "Az unzip program helyt jelzi (csak Unix). Erre zip archvumok kicsomagolsnl lesz szksg.";
$string['configuration'] = "Belltsok";
$string['configvariables'] = "Vltozk belltsa";
$string['configwarning'] = "vatosan mdostsa ezeket a belltsokat, rossz rtkek problmkat okozhatnak";
$string['configzip'] = "Az zip program helyt jelzi (csak Unix). Erre zip archvumok ltrehozsnl lesz szksg.";
$string['confirmed'] = "A regisztrcija elfogadva";
$string['confirmednot'] = "A regisztci visszaigazolsa mg nem trtnt meg!";
$string['continue'] = "Folytats";
$string['cookiesenabled'] = "A bngszjben engedlyeznie kell a cookie-kat. FIGYELEM: A nvben s a jelszban a kis s nagy betk nem ugyanannak szmtanak!!";
$string['copy'] = "msols";
$string['copyingcoursefiles'] = "Kurzus fjlok msolsa";
$string['copyinguserfiles'] = "Felhasznli fjlok msolsa";
$string['copyingzipfile'] = "Zip fjlok msolsa";
$string['copyrightnotice'] = "Szerzi jog fenntartva";
$string['country'] = "Orszg";
$string['course'] = "Tanfolyam";
$string['courseavailable'] = "A kurzus elrhet tanulk szmra";
$string['courseavailablenot'] = "A kurzus tanulk szmra nem elrhet ";
$string['coursebackup'] = "Kurzus ments";
$string['coursecategories'] = "Kurzus kategrik";
$string['coursecategory'] = "Kurzus kategria";
$string['coursecreators'] = "Kurzus ksztk";
$string['coursefiles'] = "Kurzus fjlok";
$string['courseformats'] = "Tanfolyam formk";
$string['coursegrades'] = "Kurzus jegyek";
$string['courseinfo'] = "Kurzus info";
$string['courserestore'] = "Kurzus visszalltsa";
$string['courses'] = "Tanfolyamok";
$string['courseupdates'] = "Tanfolyam frisstsek";
$string['create'] = "Ltrehozs";
$string['createaccount'] = "j felhasznl ltrehozsa";
$string['createfolder'] = "Knyvtr ltrehozsa \$a - ban";
$string['createuserandpass'] = "j felhasznlnv s jelsz ltrehozsa ";
$string['createziparchive'] = "Zip arhvum ltrehozsa";
$string['creatingcategoriesandquestions'] = "Kategrik s krdsek ltrehozsa";
$string['creatingcoursemodules'] = "Kurzus modulok ltrehozsa";
$string['creatinglogentries'] = "Napl bejegyzsek ltrehozsa";
$string['creatingnewcourse'] = "j kurzus ltrehozsa";
$string['creatingsections'] = "Szekcik ltrehozsa";
$string['creatingtemporarystructures'] = "Ideiglenes struktrk ltrehozsa";
$string['creatingusers'] = "Felhasznlk ltrehozsa";
$string['creatingxmlfile'] = "XML fjl ltrehozsa";
$string['currentlanguage'] = "Aktulis nyelv";
$string['currentlocaltime'] = "az aktulis helyi id";
$string['currentrelease'] = "Aktulis informci";
$string['currentversion'] = "Aktulis verziszm";
$string['databasechecking'] = "A Moodle adatbzis frisstse \$a->oldversion verzirl \$a->newversion verzira...";
$string['databasesetup'] = "Adatbzis ltrehozsa";
$string['databasesuccess'] = "Az adatbzis frisstse sikerlt";
$string['databaseupgradebackups'] = "A ments verziszma: \$a";
$string['databaseupgrades'] = "Az adatbzis frisstse";
$string['day'] = "nap";
$string['days'] = "nap";
$string['defaultcoursefullname'] = "A kurzus teljes neve 101";
$string['defaultcourseshortname'] = "CF101";
$string['defaultcoursestudent'] = "Tanul";
$string['defaultcoursestudents'] = "Tanulk";
$string['defaultcoursesummary'] = "Egy tmr s figyelemfelkelt bekezdst rjon arrl, hogy mirl is szl ez a kurzus";
$string['defaultcourseteacher'] = "Tanr";
$string['defaultcourseteachers'] = "Tanrok";
$string['delete'] = "Trls";
$string['deletecheck'] = "Trljem \$a -t?";
$string['deletecheckfiles'] = "Biztosan trlni szeretn ezeket a fjlokat?";
$string['deletecheckfull'] = "Biztosan trlni akarja a kvetkezt: \$a ?";
$string['deletecheckwarning'] = "A fjlok trlse";
$string['deletecompletely'] = "Teljes trls";
$string['deletecourse'] = "Tanfolyam trlse";
$string['deletecoursecheck'] = "Biztosan trlni akarja ezt a tanfolyamot s minden adatt?";
$string['deleted'] = "Trlve";
$string['deletedactivity'] = "Trlve \$a";
$string['deletedcourse'] = "\$a teljesen trlve lett";
$string['deletednot'] = "\$a nem trlhet!";
$string['deletingcourse'] = "\$a trlse";
$string['deletingexistingcoursedata'] = "Kurzus adatainak trlse";
$string['deletingolddata'] = "Rgi adatok trlse";
$string['department'] = "Osztly";
$string['description'] = "Lers";
$string['displayingfirst'] = "Csaka az els \$a->count \$a->things jelenik meg";
$string['displayingrecords'] = "\$a rekord megjelentse";
$string['displayingusers'] = "Felhasznlk megjelentse \$a->start -tl \$a->end -ig";
$string['documentation'] = "Moodle dokumentci";
$string['donotask'] = "Nem krds";
$string['downloadexcel'] = "Letlts Excel formtumban";
$string['downloadtext'] = "Letlts szveges formtumban";
$string['doyouagree'] = "Az olvasott felttelekkel egyetrt?";
$string['edit'] = "\$a szerkesztse";
$string['editcoursesettings'] = "Tanfolyam belltsok mdostsa";
$string['editinga'] = "\$a szerkesztse";
$string['editmyprofile'] = "Profil mdostsa";
$string['editsummary'] = "A szerkeszts ttekintse";
$string['editthisactivity'] = "A tevkenysg szerkesztse";
$string['editthiscategory'] = "A kategria szerkesztse";
$string['edituser'] = "A felhasznli adatok szerkesztse";
$string['email'] = "Email cm";
$string['emailconfirm'] = "Az j felhasznl elfogadva";
$string['emailconfirmation'] = "dvzljk \$a->firstname,

j felhasznl ltrehozst ignyeltk a '\$a->sitename' oldalon
e-mail cmnek felhasznlsval.

A jelentkezs visszaigazolshoz, krjk ltogasson el a
kvetkez cmre:

  \$a->link

dvzlettel:

'\$a->sitename' adminisztrtor,
\$a->admin";
$string['emailconfirmationsubject'] = "\$a: account visszaigazolsa";
$string['emailconfirmsent'] = "   <P>Egy email lett ekldve az n cmre:<B>\$a</B>
   <P>A regisztrci befejezshez szksges egyszer teendket tartalmazza.
   <P>Ha tovbbra is nehzsgekbe tkzik, lpjen kapcsolatba az oldal adminisztrtorval.";
$string['emaildisplay'] = "Email cm megmutatsa";
$string['emaildisplaycourse'] = "Csak a kurzus rsztvevi lthatjk az email cmemet";
$string['emaildisplayno'] = "Senki nem lthatja az email cmemet";
$string['emaildisplayyes'] = "Mindenki lthatja az email cmemet";
$string['emailexists'] = "Ez az email cm mr regisztrlva lett.";
$string['emailformat'] = "Email formtuma";
$string['emailmustbereal'] = "Megj.: az email-cmnek valdinak kell lennie";
$string['emailpasswordconfirmationsubject'] = "\$a: megvltozott jelsz visszaigazolsa";
$string['enrolmentkey'] = "Beiratkoz kd";
$string['enrolmentkeyfrom'] = "Ez a kurzus egy 'beiratkoz kdot' ignyel - amely egy egyszeri<br />
jelsz, mely \$a -tl kaphat meg";
$string['enrolmentkeyhint'] = "Ez a beiratkoz kdot nem megfelel, prblja jra<br />
(Egy tipp - '\$a' -val kezddik)";
$string['entercourse'] = "Kattintssal lpjen be a tanfolyamra";
$string['enteremailaddress'] = "rja be az email-cmt jelszavnak trlshez, s j jelszavnak emailen trtn elkldshez.";
$string['error'] = "Hiba";
$string['errortoomanylogins'] = "Sajnos tllpte a bejelentkezsek megengedett maximlis szmt. Indtsa jra a bngszt.";
$string['existing'] = "Ltez";
$string['existingadmins'] = "Ltez adminok";
$string['existingcourse'] = "Ltez kurzus";
$string['existingteachers'] = "Ltez tanrok";
$string['feedback'] = "Visszajelzs";
$string['filemissing'] = "\$a hinyzik";
$string['files'] = "Fjlok";
$string['filesfolders'] = "Fjlok/knyvtrak";
$string['filloutallfields'] = "Tltsn ki minden mezt ezen az rlapon";
$string['findmorecourses'] = "Tovbbi kurzusok";
$string['firstname'] = "Keresztnv";
$string['firsttime'] = "Most van itt elszr?";
$string['followingoptional'] = "A kvetkezk kitltse nem ktelez";
$string['followingrequired'] = "A kvetkezk kitltse ktelez";
$string['forgotten'] = "Elfelejtette nevt vagy jelszavt? (Csak egyszer nyomja meg, mert minden megnyomskor automatikusan j jelsz generldik, amit emailben fog megkapni)";
$string['format'] = "Formtum";
$string['formathtml'] = "HTML formtum";
$string['formatplain'] = "Szveg formtum";
$string['formatsocial'] = "Frum formtum";
$string['formattext'] = "Moodle auto-formtum";
$string['formattexttype'] = "Formtum";
$string['formattopics'] = "Tematikus formtuma";
$string['formatweeks'] = "Heti formtum";
$string['formatwiki'] = "Wiki formtum";
$string['frontpagedescription'] = "Kezd oldal lers";
$string['frontpageformat'] = "Kezd oldal formtum";
$string['fulllistofcourses'] = "Minden tanfolyam";
$string['fullname'] = "Teljes nv";
$string['fullnamedisplay'] = '$a->lastname $a->firstname';
$string['fullprofile'] = "Teljes profil";
$string['fullsitename'] = "Az oldal teljes neve";
$string['gd1'] = "GD 1.x teleptve";
$string['gd2'] = "GD 2.x teleptve";
$string['gdneed'] = "Az bra megtekintshez GD teleptse szksges";
$string['gdnot'] = "GD nincs teleptve";
$string['gpl'] = "Copyright (C) 2001-2002  Martin Dougiamas  (http://dougiamas.com)

Ez a program egy szabad szoftver; tovbbadhatja s/vagy mdosthatja a Free Software Foundation
ltal kibocstott GNU General Public License rendelkezsei szerint; vagy a License 2-es, vagy
(vlaszthat) brmely ksbbi verzi szerint.

A program annak remnyben kszlt, hogy hasznos lesz, azonban MINDEN GARANCIA NLKL; mg az ELADHATSG vagy egy SPECILIS CLRA VAL ALKALMASSG garancija nlkl is. Tovbbi rszletekrt lsd a GNU General Public License -t:

http://www.gnu.org/copyleft/gpl.html";
$string['grade'] = "Osztlyzat";
$string['grades'] = "Osztlyzatok";
$string['guestskey'] = "A vendgek belphetnek kddal";
$string['guestsno'] = "Nincs engedlyezve vendgeknek";
$string['guestsnotallowed'] = "Sajnljuk, '\$a' nem engedlyezi vendgek belpst.";
$string['guestsyes'] = "A vendgek belphetnek kd nlkl";
$string['guestuser'] = "Vendg felhasznl";
$string['guestuserinfo'] = "Ez egy specilis felhasznl, melynek csak olvassi joga van nmelyik tanfolyamhoz.";
$string['help'] = "Sg";
$string['helpformatting'] = "Szvegformzs";
$string['helphtml'] = "Hogyan rjon html-t";
$string['helpindex'] = "Sg fjlko listsa";
$string['helppicture'] = "Hogyan tltsn fel kpet";
$string['helpquestions'] = "Hogyan tegyen fel j  krdst";
$string['helpreading'] = "Olvassa el figyelmesen";
$string['helprichtext'] = "A Richtext szerkesztrl";
$string['helptext'] = "Hogyan rjon";
$string['helpwiki'] = "Wiki szveg ksztse";
$string['helpwriting'] = "rjon figyelmesen";
$string['hide'] = "Elrejts";
$string['hits'] = "Tallatok";
$string['hitsoncourse'] = "\$a->username tallatai \$a->coursename -n";
$string['hitsoncoursetoday'] = "\$a->username mai tallatai \$a->coursename -n";
$string['home'] = "Kezdlap";
$string['hour'] = "ra";
$string['hours'] = "ra";
$string['howtomakethemes'] = "j tma ksztse hogyan";
$string['htmleditor'] = "Richtext HTML szerkeszt hasznlata (csak IE 5.5-s vagy ksbbi)";
$string['htmleditoravailable'] = "A szvegformtum szerkeszt elrhet.";
$string['htmleditordisabled'] = "n kikapcsolta a Richtext szerkeszt hasznlatt a felhasznli profiljban";
$string['htmleditordisabledadmin'] = "Az adminisztrtor nem engedlyezte a Richtext szerkeszt hasznlatt ezen az oldalon";
$string['htmleditordisabledbrowser'] = "A Richtext szerkeszt nem elrhet, mert nem Internet Explorer 5.5 vagy jabb verzit hasznl";
$string['htmlformat'] = "Szp HTML formtum";
$string['icqnumber'] = "ICQ szm";
$string['idnumber'] = "ID szm";
$string['invalidemail'] = "rvnytelen email cm";
$string['invalidlogin'] = "rvnytelen bejelentkezs, prblja jra";
$string['jumpto'] = "Ugrs...";
$string['langltr'] = "rs irnya balrl-jobbra";
$string['langrtl'] = "rs irnya jobbrl balra";
$string['language'] = "Nyelv";
$string['languagegood'] = "Ez a nyelvi csomag egsz friss! :-)";
$string['lastaccess'] = "Utoljra itt jrt";
$string['lastedited'] = "Utoljra szerkesztve";
$string['lastmodified'] = "Utoljra mdostva";
$string['lastname'] = "Vezetknv";
$string['latestnews'] = "Legfrisebb hrek";
$string['leavetokeep'] = "Hagyja resen a jelenlegi jelsz megrzshez";
$string['license'] = "GPL License";
$string['list'] = "Lista";
$string['listfiles'] = "\$a -beli fjlok listja";
$string['listofallpeople'] = "Az sszes szemly listja";
$string['livelogs'] = "Napl a legutols rrl";
$string['locale'] = "hu";
$string['location'] = "Hely";
$string['loggedinas'] = "\$a nven jelentkezett be";
$string['loggedinnot'] = "Nincs bejelentkezve.";
$string['login'] = "Bejelentkezs";
$string['loginas'] = "Bejelentkezs mint";
$string['loginguest'] = "Bejelentkezs vendgknt";
$string['loginsite'] = "Belps az oldalra";
$string['loginsteps'] = "dv! Ahhoz, hogy teljesen hozzfrjen a kurzusokhoz, j felhasznlt kell ltrehoznia ehhez a weboldalhoz.
   Minden kurzus ignyelhet egy egyszeri
   &quot;beiratkoz kdot&quot;, amelyre egyelre nincs szksge. A vgrehajtand lpsek:
   <OL size=2>
   <LI>Tltse ki az <A HREF=\$a>j felhasznl</A> rlap adatait.
   <LI>Egy email elkldsre kerl sor az n cmre, rgtn a kitlts utn.
   <LI>Olvassa el az email-t, s kattintson a benne tallt hivatkozsra.
   <LI>Az j felhasznl ekkor megerstst nyer, s n be lesz jelentkezve.
   <LI>Ekkor vlassza ki azt a kurzust, melynek rsztvevje kvn lenni.
   <LI>Ha egy &quot;beiratkoz kdra&quot; van szksg - rja be azt, melyet az oktat adott nnek. Ezzel &quot;beiratkozott&quot; a kurzusra.
   <LI>Ezutn teljes hozzfre van a kurzushoz. A tovbbiakban csak a felhasznlnevt s jelszavt kell bernia (ezen az oldalon) a bejelentkezshez, s minden kurzushoz hozzfr, melyre beiratkozott.
   </OL>";
$string['loginstepsnone'] = "dv!<P>Ahhoz, hogy teljesen hozzfrjen a kurzusokhoz, j felhasznlt kell ltrehoznia.<P>Csupn egy felhasznlnevet s jelszt kell ltrehoznia, azutn bernia ezen az oldalon!<P>Ha valaki mr vlasztotta a kvnt felhasznlnevet,
akkor jra kell prblkoznia egy msik nvvel.";
$string['loginto'] = "Belps \$a -ra";
$string['loginusing'] = "Lpjen be itt a nevvel s a jelszavval";
$string['logout'] = "Kilps";
$string['logs'] = "Naplk";
$string['mainmenu'] = "Fmen";
$string['makeafolder'] = "Knyvtr ltrehozsa";
$string['makeeditable'] = "Ha '\$a' -t a webszerver processz ltal (pl. apache) rhatv teszi, akkor ezt a fjlt kzvetlenl szerkesztheti errl az oldalrl";
$string['managedatabase'] = "Adatbziskezels";
$string['managemodules'] = "Modulok";
$string['markthistopic'] = "A tma kivlasztsa aktulis tmnak";
$string['maximumchars'] = "Maximum \$a karakter";
$string['maximumgrade'] = "Maximum osztlyzat";
$string['maximumshort'] = "Max";
$string['maxsize'] = "Max mret: \$a";
$string['min'] = "min";
$string['mins'] = "min";
$string['miscellaneous'] = "Egyb";
$string['missingcategory'] = "Kategrit kell vlasztania";
$string['missingcity'] = "Hinyz vros";
$string['missingcountry'] = "Hinyz orszg";
$string['missingdescription'] = "Hinyz lers";
$string['missingemail'] = "Hinyz email cm";
$string['missingfirstname'] = "Hinyz keresztnv";
$string['missingfullname'] = "Hinyz teljes nv";
$string['missinglastname'] = "Hinyz vezetknv";
$string['missingnewpassword'] = "Hinyz j jelsz";
$string['missingpassword'] = "Hinyz jelsz";
$string['missingshortname'] = "Hinyz rvid nv";
$string['missingshortsitename'] = "Hinyz oldal rvid nv";
$string['missingsitedescription'] = "Hinyz oldal lers";
$string['missingsitename'] = "Hinyz oldal nv";
$string['missingstrings'] = "Hinyz szvegek keresse";
$string['missingstudent'] = "Vlasztania kell valamit";
$string['missingsummary'] = "Hinyz tartalom";
$string['missingteacher'] = "Hinyz tanr";
$string['missingurl'] = "Hinyz URL";
$string['missingusername'] = "Hinyz felhasznlnv";
$string['modified'] = "Mdostva";
$string['modulesetup'] = "Modul tblk ltrehozsa";
$string['modulesuccess'] = "A \$a tblk ltrehozsa sikerlt";
$string['moodleversion'] = "Moodle verzi";
$string['mostrecently'] = "legutoljra";
$string['move'] = "Mozgats";
$string['movecategoryto'] = "Kategria mozgatsa a kvetkez helyre:";
$string['movecourseto'] = "Kurzus mozgatsa a kvetkez helyre:";
$string['movedown'] = "Le";
$string['movefilestohere'] = "Fjlok mozgatsa ide";
$string['movefull'] = "\$a mozgatsa ide";
$string['movehere'] = "Mozgats ide";
$string['moveselectedcoursesto'] = "A kivlasztott kurzusok mozgatsa a kvetkez helyre:";
$string['movetoanotherfolder'] = "Mozgats msik knyvtrba";
$string['moveup'] = "Fel";
$string['mustconfirm'] = "Meg kell erstenie a bejelentkezst";
$string['mycourses'] = "Az n kurzusai";
$string['name'] = "Nv";
$string['namesocial'] = "szekci";
$string['nametopics'] = "tematikus";
$string['nameweeks'] = "heti";
$string['needed'] = "Kell";
$string['never'] = "Soha";
$string['new'] = "j";
$string['newaccount'] = "j felhasznl";
$string['newcourse'] = "j kurzus";
$string['newpassword'] = "j jelsz";
$string['newpasswordtext'] = "dvzljk \$a->firstname,

Az n jelszava az '\$a->sitename' oldalon megvltozott s egy j ideiglenes jelszavat kapott.

A jelenlegi bejelentkezsi informcii:
   nv: \$a->username
   jelsz: \$a->newpassword

Krjk ltogasson a kvetkez oldalra a jelsz megvltoztatshoz:
   \$a->link

dvzlettel
'\$a->sitename' Adminisztrtor,
\$a->signoff
";
$string['newpicture'] = "j kp (csak jpg formtum)";
$string['newsitem'] = "hr";
$string['newsitems'] = "hrek";
$string['newsitemsnumber'] = "Megjelentend hrek";
$string['newuser'] = "j felhasznl";
$string['newusers'] = "j felhasznlk";
$string['next'] = "Kvetkez";
$string['no'] = "Nem";
$string['nocoursesyet'] = "Ebben a kategriban nincsenek tanfolyamok";
$string['noexistingadmins'] = "Nincs admin, ez egy komoly hiba, ennek soha nem szabadna megjelennie.";
$string['noexistingcreators'] = "Nincsenek ksztk";
$string['noexistingstudents'] = "Nincsenek tanulk";
$string['noexistingteachers'] = "Nincsenek tanrok";
$string['nofilesselected'] = "Nincs fjl kivlasztva";
$string['nofilesyet'] = "Ehhez a tanfolyamhoz mg nincsenek fjlok feltltve.";
$string['nograde'] = "Nincs osztlyzat";
$string['noimagesyet'] = "Ehhez a tanfolyamhoz mg nincsenek kpek feltltve.";
$string['none'] = "Nincs";
$string['nopotentialadmins'] = "Nincs lehetsges admin";
$string['nopotentialcreators'] = "Nincs lehetsges kszt";
$string['nopotentialstudents'] = "Nincs lehetsges tanul";
$string['nopotentialteachers'] = "Nincs lehetsges tanr";
$string['normal'] = "Norml";
$string['nostudentsyet'] = "Ehhez a tanfolyamhoz mg nem iratkoztak be dikok";
$string['nosuchemail'] = "Nincs ilyen email cm";
$string['notavailable'] = "Nem elrhet";
$string['noteachersyet'] = "Ehhez a tanfolyamhoz mg nincsenek tanrok";
$string['notenrolled'] = "\$a nem iratkozott fel erre a tanfolyamra.";
$string['nothingnew'] = "Semmi jdonsg az utols belps ta";
$string['nousersyet'] = "Mg nincsenek felhasznlk";
$string['now'] = "most";
$string['numberweeks'] = "Hetek/tmk szma";
$string['numdays'] = "\$a nap";
$string['numhours'] = "\$a ra";
$string['numminutes'] = "\$a perc";
$string['numviews'] = "\$a nzet";
$string['numweeks'] = "\$a ht";
$string['numwords'] = "\$a sz";
$string['numyears'] = "\$a v";
$string['ok'] = "OK";
$string['opentoguests'] = "Vendg hozzfrs";
$string['optional'] = "vlaszthat";
$string['order'] = "Sorrend";
$string['outline'] = "Forma";
$string['page'] = "Oldal";
$string['participants'] = "Rsztvevk";
$string['password'] = "Jelsz";
$string['passwordchanged'] = "A jelsz megvltozott";
$string['passwordconfirmchange'] = "Jelszvltoztats megerstse";
$string['passwordrecovery'] = "Igen, krek segtsget a belpshez";
$string['passwordsdiffer'] = "A jelszavak nem megfelelek";
$string['passwordsent'] = "A jelsz elkldve";
$string['passwordsenttext'] = "   <P>Egy email lett elkldve az n cmre: \$a->email.
   <P><B>Krjk olvassa el a levelet az j jelszrt</B>
   <P>Az j jelsz automatikusan jtt ltre, gy lehet, hogy n meg szeretn
   <A HREF=\$a->link>vltoztatni egy knnyebben megjegyezhetre</A>.";
$string['people'] = "Szemlyek";
$string['personalprofile'] = "Szemlyes profil";
$string['phone'] = "Telefon";
$string['phpinfo'] = "PHP info";
$string['popupwindow'] = "Fjl megnyitsa j ablakban";
$string['potentialadmins'] = "Lehetsges adminok";
$string['potentialcreators'] = "Lehetsges ksztk";
$string['potentialstudents'] = "Lehetsges tanulk";
$string['potentialteachers'] = "Lehetsges tanrok";
$string['preferredlanguage'] = "Vlasztott nyelv";
$string['preview'] = "Elnzet";
$string['previeworchoose'] = "Egy stlus megtekintse vagy kivlasztsa";
$string['question'] = "Krds";
$string['readme'] = "OLVASSEL";
$string['recentactivity'] = "Legutbbi tevkenysg";
$string['registrationno'] = "Nem, nem szeretnk e-amilt kapni";
$string['removeadmin'] = "Admin trlse";
$string['removecreator'] = "Kszt eltvoltsa";
$string['removestudent'] = "Tanul eltvoltsa";
$string['removeteacher'] = "Tanr trlse";
$string['rename'] = "tnevezs";
$string['renamefileto'] = "<b>\$a</b> tnevezse a kvetkezre: ";
$string['requireskey'] = "A tanfolyam egy 'beiratkoz kdot ignyel'";
$string['resources'] = "Tananyagok";
$string['restore'] = "Visszallts";
$string['restorecancelled'] = "A visszallts nem trtnt meg";
$string['restorecoursenow'] = "A kurzus visszalltsa most!";
$string['restorefinished'] = "A visszallts sikerlt";
$string['returningtosite'] = "Visszatrs erre az oldalra?";
$string['revert'] = "Visszatrs";
$string['role'] = "Szerep";
$string['savechanges'] = "Vltozs mentse";
$string['search'] = "Keress";
$string['searchagain'] = "Keress tovbb";
$string['searchresults'] = "Keress eredmnye";
$string['sec'] = "mp";
$string['secs'] = "mp";
$string['section'] = "Szekci";
$string['select'] = "Kivlaszts";
$string['selectacountry'] = "Vlaszzon egy orszgot";
$string['senddetails'] = "Rszletek kldse email-ben";
$string['separateandconnected'] = "Separate and Connected ways of knowing";
$string['serverlocaltime'] = "Szerver helyi id";
$string['settings'] = "Belltsok";
$string['shortname'] = "Rvid nv";
$string['shortsitename'] = "Az oldal rvid neve (pl. egy sz)";
$string['show'] = "Megtekints";
$string['showall'] = "Minden \$a megjelentse";
$string['showallcourses'] = "Minden tanfolyam mutatsa";
$string['showalltopics'] = "Minden tma mutatsa";
$string['showallusers'] = "Minden felhasznl megjelentse";
$string['showallweeks'] = "Minden ht mutatsa";
$string['showlistofcourses'] = "tanfolyamlista mutatsa";
$string['showonlytopic'] = "Csak \$a tma mutatsa";
$string['showonlyweek'] = "Csak \$a ht mutatsa";
$string['showrecent'] = "Legutbbi aktivits megtekintse";
$string['showtheselogs'] = "Naplk megtekintse";
$string['site'] = "Oldal";
$string['sitelogs'] = "Az oldal naplja";
$string['sitenews'] = "jdonsgok az oldalon";
$string['sites'] = "Oldalak";
$string['sitesettings'] = "Az oldal belltsai";
$string['size'] = "Mret";
$string['socialheadline'] = "Kzs frum - legutbbi tmk";
$string['someallowguest'] = "Nhny kurzus megengedheti a vendgek hozzfrst";
$string['someerrorswerefound'] = "Valamilyen informci hinyzik, vagy hibs. A rszleteket lsd lentebb.";
$string['startdate'] = "A kurzus kezd dtuma";
$string['startsignup'] = "Kezdje j felhasznl ltrehozsval!";
$string['status'] = "Sttusz";
$string['stringsnotset'] = "A kvetekz szvegek nincsenek megadva \$a -ban";
$string['studentnotallowed'] = "Erre a tanfolyamra sajnos nem tud belpni '\$a' -knt";
$string['subcategories'] = "Alkategrik";
$string['success'] = "Sikerlt";
$string['summary'] = "sszefoglal";
$string['summaryof'] = "\$a sszefoglalja";
$string['supplyinfo'] = "Adjon magrl nmi informcit";
$string['teacheronly'] = "csak \$a szmra";
$string['teachers'] = "Tanrok";
$string['textediting'] = "Szveg szerkesztsekor";
$string['texteditor'] = "Standard web rlapok hsznlata";
$string['textformat'] = "Egyszer szveg formtum";
$string['thanks'] = "Ksznjk";
$string['theme'] = "Stlus";
$string['themes'] = "Stlusok";
$string['themesaved'] = "j stlus mentve";
$string['thischarset'] = "iso-8859-2";
$string['thislanguage'] = "Magyar";
$string['time'] = "Id";
$string['timezone'] = "Idzna";
$string['today'] = "Ma";
$string['todaylogs'] = "Mai napl";
$string['toomanytoshow'] = "Tl sok felhasznl";
$string['topic'] = "Tma";
$string['topicoutline'] = "Tantrgyak";
$string['total'] = "sszes";
$string['turneditingoff'] = "Szerkeszts kikapcsolsa";
$string['turneditingon'] = "Szerkeszts bekapcsolsa";
$string['undecided'] = "Nincs megadva";
$string['unenrol'] = "Kiiratkozs";
$string['unenrolme'] = "Kiiratkozom \$a -rl";
$string['unenrolsure'] = "Biztosan ki akarja iratni \$a -t errl a kurzusrl?";
$string['unknowncategory'] = "Ismeretlen kategria";
$string['unsafepassword'] = "Nem biztonsgos jelsz - prbljon egy msikat";
$string['unusedaccounts'] = "A \$a napnl hosszabb ideig nem hasznlt felhasznlnv automatikusan kiiratkozik";
$string['unzip'] = "Unzip";
$string['update'] = "Frissts";
$string['updated'] = "\$a frisstve";
$string['updatemyprofile'] = "A profil frisstse";
$string['updatesevery'] = "Frissts minden \$a mpben";
$string['updatethis'] = "\$a frisstse";
$string['updatethiscourse'] = "A tanfolyam frisstse";
$string['updatinga'] = "Egy \$a frisstse";
$string['updatingain'] = "Egy \$a->what frisstse \$a->in -ban";
$string['upload'] = "Feltlts";
$string['uploadafile'] = "Egy fjl feltltse";
$string['uploadedfileto'] = "\$a->file feltltve a \$a- >directory knyvtrba";
$string['uploadnofilefound'] = "Nincs ilyen fjl. Biztos benne, hogy kivlasztott egyet feltltsre?";
$string['uploadproblem'] = "Ismeretlen problma lpett fel az '\$a' fjl feltltsekor (taln tl nagy a fjl?)";
$string['uploadthisfile'] = "A fjl feltltse";
$string['user'] = "Felhasznl";
$string['userdeleted'] = "Ez a felhasznl trlve lett";
$string['userdescription'] = "Lers";
$string['username'] = "Felhasznlnv";
$string['usernameexists'] = "A felhasznlnv mr ltezik, vlasszon msikat";
$string['userprofilefor'] = "Felhasznli profil \$a szmra";
$string['users'] = "Felhasznlk";
$string['webpage'] = "Honlap";
$string['week'] = "Ht";
$string['weeklyoutline'] = "Heti formtum";
$string['welcometocourse'] = "dvzljk \$a -n";
$string['welcometocoursetext'] = "dvzljk a \$a->coursename kurzuson!

Taln az els dolog, amit rdemes megtenni: lltsa be az n felhasznli profiljt,
hogy tbbet megtudjunk nrl:

  \$a->profileurl";
$string['withchosenfiles'] = "A vlasztott fjlokkal";
$string['wordforstudent'] = "Az n szava a Tanulra";
$string['wordforstudenteg'] = "pl. Tanul, Rsztvev stb.";
$string['wordforstudents'] = "Az n szava a Tanulkra";
$string['wordforstudentseg'] = "pl. Tanulk, Rsztvevk stb.";
$string['wordforteacher'] = "Az n szava a Tanrra";
$string['wordforteachereg'] = "pl. Tanr, Oktat, Segt stb";
$string['wordforteachers'] = "Az n szava a Tanrokra";
$string['wordforteacherseg'] = "pl. Tanrok, Oktatk, Segtk stb";
$string['wrongpassword'] = "A jelsz ehhez a nvhez nem megfelel";
$string['yes'] = "Igen";
$string['yourlastlogin'] = "Az utols bejelentkezse:";
$string['yourself'] = "n";
$string['yourteacher'] = "az n \$a -ja";

?>
